%!TEX encoding = UTF-8 Unicode
%
% Translation completed on 2006/01/13
\ProvidesFile{ecvlv.def}[europecv Latvian definitions]
% Personal information
\def\ecv@infosectionkey{\ecv@utf{Personas dati}}
\def\ecv@namekey{\ecv@utf{Uzv{\=a}rds / V{\=a}rds}}
\def\ecv@addresskey{\ecv@utf{Adrese}}
\def\ecv@telkey{\ecv@utf{T{\=a}lrunis}}
\def\ecv@mobilekey{\ecv@utf{Mobilais t{\=a}lrunis}}
\def\ecv@faxkey{\ecv@utf{Fakss}}
\def\ecv@emailkey{\ecv@utf{E-pasts}}
\def\ecv@nationalitykey{\ecv@utf{Pilson{\=\i}ba}}
\def\ecv@birthkey{\ecv@utf{Dzim{\v s}anas datums}}
\def\ecv@genderkey{\ecv@utf{Dzimums}}
% Footer
\def\ecv@pagekey{\ecv@utf{Lapa}}
\def\ecv@cvofkey{\ecv@utf{Curriculum Vit\ae}}
% Language table
\def\ecv@mothertonguekey{\ecv@utf{Dzimt{\=a} valoda}}
\def\ecv@assesskey{\ecv@utf{Pa{\v s}nov{\=e}rt{\=e}jums}}
\def\ecv@levelkey{\ecv@utf{Eiropas l{\=\i}menis}}
\def\ecv@understandkey{\ecv@utf{Sapatne}}
\def\ecv@speakkey{\ecv@utf{Run{\=a}{\v s}ana}}
\def\ecv@writekey{\ecv@utf{Rakst{\=\i}{\v s}ana}}
\def\ecv@listenkey{\ecv@utf{Klaus{\=\i}{\v s}an{\=a}s}}
\def\ecv@readkey{\ecv@utf{Las{\=\i}{\v s}ana}}
\def\ecv@interactkey{\ecv@utf{Dialogs}}
\def\ecv@productkey{\ecv@utf{Monologs}}
\def\ecv@langfooterkey{\ecv@utf{Eiropas kop{\=\i}g{\=a}m pamatnost{\=a}dn{\=e}m valodu apguv{\=e} atbilsto{\v s}s l{\=\i}menis}}
\def\ecv@cefbasickey{\ecv@utf{Pamatl{\=\i}menis}}
\def\ecv@cefindepkey{\ecv@utf{Vid{\=e}jais l{\=\i}menis}}
\def\ecv@cefprofkey{\ecv@utf{Augst{\=a}kais l{\=\i}menis}}
