%!TEX encoding = UTF-8 Unicode
%
% Translation completed on 2005/04/08
\ProvidesFile{ecvpl.def}[europecv Polish definitions]
% Personal information
\def\ecv@infosectionkey{\ecv@utf{Dane osobowe}}
\def\ecv@namekey{\ecv@utf{Nazwisko / Imi\k{e}}}
\def\ecv@addresskey{\ecv@utf{Adres(y)}}
\def\ecv@telkey{\ecv@utf{Telefon(y)}}
\def\ecv@mobilekey{\ecv@utf{Tel. kom.}}
\def\ecv@faxkey{\ecv@utf{Faks(y)}}
\def\ecv@emailkey{\ecv@utf{Email(e)}}
\def\ecv@nationalitykey{\ecv@utf{Obywatelstwo}}
\def\ecv@birthkey{\ecv@utf{Data urodzenia}}
\def\ecv@genderkey{\ecv@utf{P{\l}e\'c}}
% Footer
\def\ecv@pagekey{\ecv@utf{Strona}}
\def\ecv@cvofkey{\ecv@utf{Curriculum vit\ae}}
% Language table
\def\ecv@mothertonguekey{\ecv@utf{J\k{e}zyk ojczysty}}
\def\ecv@assesskey{\ecv@utf{Samoocena umiej\k{e}tno\'sci j\k{e}zykowych}}
\def\ecv@levelkey{\ecv@utf{Poziom europejski}}
\def\ecv@understandkey{\ecv@utf{Rozumienie}}
\def\ecv@speakkey{\ecv@utf{M\'owienie}}
\def\ecv@writekey{\ecv@utf{Pisanie}}
\def\ecv@listenkey{\ecv@utf{S{\l}uchanie}}
\def\ecv@readkey{\ecv@utf{Czytanie}}
\def\ecv@interactkey{\ecv@utf{Porozumiewanie si\k{e}}}
\def\ecv@productkey{\ecv@utf{Samodzielne wypowiadanie si\k{e}}}
\def\ecv@langfooterkey{\ecv@utf{Europejski system opisu kszta{\l}cenia j\k{e}zykowego }}
\def\ecv@cefbasickey{\ecv@utf{Poziom podstawowy}}
\def\ecv@cefindepkey{\ecv@utf{Poziom samodzielno\'sci}}
\def\ecv@cefprofkey{\ecv@utf{Poziom bieg{\l}o\'sci}}
