%!TEX encoding = UTF-8 Unicode
%
% Translation completed on 2006/01/13
\ProvidesFile{ecvbg.def}[europecv Bulgarian definitions]
% Personal information
\def\ecv@infosectionkey{\ecv@utf{Лична информация}}
\def\ecv@namekey{\ecv@utf{Фамилия (ии), Собствено (и) име (на)}}
\def\ecv@addresskey{\ecv@utf{Адрес}}
\def\ecv@telkey{\ecv@utf{Телефон}}
\def\ecv@mobilekey{\ecv@utf{Мобилен телефон}}
\def\ecv@faxkey{\ecv@utf{Факс}}
\def\ecv@emailkey{\ecv@utf{E-mail}}
\def\ecv@nationalitykey{\ecv@utf{Националност}}
\def\ecv@birthkey{\ecv@utf{Дата на раждане}}
\def\ecv@genderkey{\ecv@utf{Пол}}
% Footer
\def\ecv@pagekey{\ecv@utf{Cтр.}}
\def\ecv@cvofkey{\ecv@utf{Europass Автобиографияf}}
% Language table
\def\ecv@mothertonguekey{\ecv@utf{Майчин (и) език (езици)}}
\def\ecv@assesskey{\ecv@utf{Самооценяване}}
\def\ecv@levelkey{\ecv@utf{Европейско ниво}}
\def\ecv@understandkey{\ecv@utf{Разбиране}}
\def\ecv@speakkey{\ecv@utf{Разговор}}
\def\ecv@writekey{\ecv@utf{Писане}}
\def\ecv@listenkey{\ecv@utf{Слушане}}
\def\ecv@readkey{\ecv@utf{Четене}}
\def\ecv@interactkey{\ecv@utf{Участие в разговор}}
\def\ecv@productkey{\ecv@utf{Самостоятелно устно изложение}}
\def\ecv@langfooterkey{\ecv@utf{Единни европейски критерии за познания по езици}}
\def\ecv@cefbasickey{\ecv@utf{Ниво на владеене - основно}}
\def\ecv@cefindepkey{\ecv@utf{Ниво на владеене - самостоятелно}}
\def\ecv@cefprofkey{\ecv@utf{Ниво на владеене - свободно}}

\renewcommand*\ecvtitle{\ecv@utf{\Large\textbf{E\ecv@kern u\ecv@kern
r\ecv@kern o\ecv@kern p\ecv@kern a\ecv@kern s\ecv@kern s}\\[5pt]
\Large\textbf{а\ecv@kern в\ecv@kern т\ecv@kern о\ecv@kern б\ecv@kern и\ecv@kern о\ecv@kern г\ecv@kern р\ecv@kern а\ecv@kern ф\ecv@kern и\ecv@kern я}}}
