%!TEX encoding = UTF-8 Unicode
%
% Translation completed on 2006/01/11
\ProvidesFile{ecvhu.def}[europecv Hungarian definitions]
% Personal information
\def\ecv@infosectionkey{\ecv@utf{Szem\'elyi adatok}}
\def\ecv@namekey{\ecv@utf{Vezet\'ekn\'ev/Ut\'on\'ev}}
\def\ecv@addresskey{\ecv@utf{C\'\i m}}
\def\ecv@telkey{\ecv@utf{Telefonsz\'am}}
\def\ecv@mobilekey{\ecv@utf{Mobil}}
\def\ecv@faxkey{\ecv@utf{Fax}}
\def\ecv@emailkey{\ecv@utf{E-mail}}
\def\ecv@nationalitykey{\ecv@utf{\'Allampolg\'ars\'ag}}
\def\ecv@birthkey{\ecv@utf{Sz\"ulet\'esi d\'atum}}
\def\ecv@genderkey{\ecv@utf{Neme}}
% Footer
\def\ecv@pagekey{\ecv@utf{oldal}}
\def\ecv@cvofkey{\ecv@utf{\"On\'eletrajza}}
% Language table
\def\ecv@mothertonguekey{\ecv@utf{Anyanyelv(ek)}}
\def\ecv@assesskey{\ecv@utf{\"On\'ert\'ekel\'es}}
\def\ecv@levelkey{\ecv@utf{Eur\'opai szint}}
\def\ecv@understandkey{\ecv@utf{Sz\"oveg\'ert\'es}}
\def\ecv@speakkey{\ecv@utf{Besz\'ed}}
\def\ecv@writekey{\ecv@utf{\'Ir\'as}}
\def\ecv@listenkey{\ecv@utf{Hall\'as ut\'ani \'ert\'es}}
\def\ecv@readkey{\ecv@utf{Olvas\'as}}
\def\ecv@interactkey{\ecv@utf{T\'arsalg\'as}}
\def\ecv@productkey{\ecv@utf{Folyamatos besz\'ed}}
\def\ecv@langfooterkey{\ecv@utf{K\"oz\"os Eur\'opai Referenciakeret (KER) szintjei}}
\def\ecv@cefbasickey{\ecv@utf{alapszint\H u nyelvhaszn\'al\'o}}
\def\ecv@cefindepkey{\ecv@utf{\"on\'all\'o nyelvhaszn\'al\'o}}
\def\ecv@cefprofkey{\ecv@utf{mesterfok\'u nyelvhaszn\'al\'o}}

\renewcommand*\ecvtitle{\ecv@utf{\Large\textbf{E\ecv@kern u\ecv@kern
r\ecv@kern o\ecv@kern p\ecv@kern a\ecv@kern s\ecv@kern s}\\[5pt]
\Large\textbf{\"O\ecv@kern n\ecv@kern \'e\ecv@kern l\ecv@kern
e\ecv@kern t\ecv@kern r\ecv@kern a\ecv@kern j\ecv@kern z}}}

