%!TEX encoding = UTF-8 Unicode
%
% Translation completed on 2006/03/23
\ProvidesFile{ecvgl.def}[europecv Galician definitions]
% Personal information
\def\ecv@infosectionkey{\ecv@utf{Informaci\'on persoal}}
\def\ecv@namekey{\ecv@utf{Apelidos / Nome}}
\def\ecv@addresskey{\ecv@utf{Direcci\'on}}
\def\ecv@telkey{\ecv@utf{Tel\'efono}}
\def\ecv@mobilekey{\ecv@utf{M\'obil}}
\def\ecv@faxkey{\ecv@utf{Fax(es)}}
\def\ecv@emailkey{\ecv@utf{Correo electr\'onico}}
\def\ecv@nationalitykey{\ecv@utf{Nacionalidade}}
\def\ecv@birthkey{\ecv@utf{Data de nacemento}}
\def\ecv@genderkey{\ecv@utf{Sexo}}
% Footer
\def\ecv@pagekey{\ecv@utf{P\'axina}}
\def\ecv@cvofkey{\ecv@utf{Curriculum vit\ae\ de}}
% Language table
\def\ecv@mothertonguekey{\ecv@utf{Lingua materna}}
\def\ecv@assesskey{\ecv@utf{Auto avaliaci\'on}}
\def\ecv@levelkey{\ecv@utf{Nivel europeo}}
\def\ecv@understandkey{\ecv@utf{Comprensi\'on}}
\def\ecv@speakkey{\ecv@utf{Fala}}
\def\ecv@writekey{\ecv@utf{Escritura}}
\def\ecv@listenkey{\ecv@utf{Comprensi\'on auditiva}}
\def\ecv@readkey{\ecv@utf{Comprensi\'on lectora}}
\def\ecv@interactkey{\ecv@utf{Interacci\'on oral}}
\def\ecv@productkey{\ecv@utf{Expresión oral}}
\def\ecv@langfooterkey{\ecv@utf{Nivel do Marco Europeo Com\'un de Referencia (MECR)}}
\def\ecv@cefbasickey{\ecv@utf{Usuario b\'asico}}
\def\ecv@cefindepkey{\ecv@utf{Usuario \mbox{independente}}}
\def\ecv@cefprofkey{\ecv@utf{Usuario \mbox{competente}}}

\renewcommand*\ecvtitle{\ecv@utf{\Large\textbf{C\ecv@kern u\ecv@kern r\ecv@kern r\ecv@kern i\ecv@kern c\ecv@kern u\ecv@kern l\ecv@kern u\ecv@kern m \ecv@kern v\ecv@kern i\ecv@kern t\ecv@kern a\ecv@kern e}\\[5pt]
\Large\textbf{E\ecv@kern u\ecv@kern
r\ecv@kern o\ecv@kern p\ecv@kern a\ecv@kern s\ecv@kern s}}}

