%!TEX encoding = UTF-8 Unicode
%
% Translation completed on 2005/04/08
\ProvidesFile{ecvde.def}[europecv German definitions]
% Personal information
\def\ecv@infosectionkey{\ecv@utf{Angaben zur Person}}
\def\ecv@namekey{\ecv@utf{Nachname(n) / Vorname(n)}}
\def\ecv@addresskey{\ecv@utf{Adresse(n)}}
\def\ecv@telkey{\ecv@utf{Telefon}}
\def\ecv@mobilekey{\ecv@utf{Mobil}}
\def\ecv@faxkey{\ecv@utf{Fax}}
\def\ecv@emailkey{\ecv@utf{E-mail}}
\def\ecv@nationalitykey{\ecv@utf{Staatsangeh\"origkeit(en)}}
\def\ecv@birthkey{\ecv@utf{Geburtsdatum}}
\def\ecv@genderkey{\ecv@utf{Geschlecht}}
% Footer
\def\ecv@pagekey{\ecv@utf{Seite}}
\def\ecv@cvofkey{\ecv@utf{Lebenslauf von}}
% Language table
\def\ecv@mothertonguekey{\ecv@utf{Muttersprache(n)}}
\def\ecv@assesskey{\ecv@utf{Selbstbeurteilung}}
\def\ecv@levelkey{\ecv@utf{Europ\"aische Kompetenzstufe}}
\def\ecv@understandkey{\ecv@utf{Verstehen}}
\def\ecv@speakkey{\ecv@utf{Sprechen}}
\def\ecv@writekey{\ecv@utf{Schreiben}}
\def\ecv@listenkey{\ecv@utf{H\"oren}}
\def\ecv@readkey{\ecv@utf{Lesen}}
\def\ecv@interactkey{\ecv@utf{An Gespr\"achen teilnehmen}}
\def\ecv@productkey{\ecv@utf{Zusammen\-h\"angendes Sprechen}}
\def\ecv@langfooterkey{\ecv@utf{Kompetenzstufe des gemeinsamen europ\"aischen Referenzrahmens}}
\def\ecv@cefbasickey{\ecv@utf{Elementare Sprachverwendung}}
\def\ecv@cefindepkey{\ecv@utf{Selbst\"andige Sprachverwendung}}
\def\ecv@cefprofkey{\ecv@utf{Kompetente Sprachverwendung}}

\renewcommand*\ecvtitle{\ecv@utf{\Large\textbf{E\ecv@kern u\ecv@kern
r\ecv@kern o\ecv@kern p\ecv@kern a\ecv@kern s\ecv@kern s}\\[5pt]
\Large\textbf{L\ecv@kern e\ecv@kern b\ecv@kern e\ecv@kern
n\ecv@kern s\ecv@kern l\ecv@kern a\ecv@kern u\ecv@kern f\ecv@kern}}}
