%!TEX encoding = UTF-8 Unicode
%
% Translation completed on 2006/01/11
\ProvidesFile{ecvnl.def}[europecv Dutch definitions]
% Personal information
\def\ecv@infosectionkey{\ecv@utf{Persoonsgegevens}}
\def\ecv@namekey{\ecv@utf{Achternaam~(-namen)/ Voornaam~(-namen)}}
\def\ecv@addresskey{\ecv@utf{Adres(sen)}}
\def\ecv@telkey{\ecv@utf{Telefoon(s)}}
\def\ecv@mobilekey{\ecv@utf{Mobiel}}
\def\ecv@faxkey{\ecv@utf{Faxnummer(s)}}
\def\ecv@emailkey{\ecv@utf{E-mailadres(sen)}}
\def\ecv@nationalitykey{\ecv@utf{Nationaliteit}}
\def\ecv@birthkey{\ecv@utf{Geboortedatum}}
\def\ecv@genderkey{\ecv@utf{Geslacht}}
% Footer
\def\ecv@pagekey{\ecv@utf{Pagina}}
\def\ecv@cvofkey{\ecv@utf{Curriculum vit\ae\ van}}
% Language table
\def\ecv@mothertonguekey{\ecv@utf{Moedertaal~(-talen)}}
\def\ecv@assesskey{\ecv@utf{Zelfevaluatie}}
\def\ecv@levelkey{\ecv@utf{Europees niveau}}
\def\ecv@understandkey{\ecv@utf{Begrijpen}}
\def\ecv@speakkey{\ecv@utf{Spreken}}
\def\ecv@writekey{\ecv@utf{Schrijven}}
\def\ecv@listenkey{\ecv@utf{Luisteren}}
\def\ecv@readkey{\ecv@utf{Lezen}}
\def\ecv@interactkey{\ecv@utf{Interactie}}
\def\ecv@productkey{\ecv@utf{Productie}}
\def\ecv@langfooterkey{\ecv@utf{Europees Referentiekader Taalvaardigheidsonderwijs}}
\def\ecv@cefbasickey{\ecv@utf{Beginnend taalgebruiker}}
\def\ecv@cefindepkey{\ecv@utf{Onafhankelijk taalgebruiker}}
\def\ecv@cefprofkey{\ecv@utf{Vaardig taalgebruiker}}
