%!TEX encoding = UTF-8 Unicode
%
% Translation completed on 2006/01/13
\ProvidesFile{ecvis.def}[europecv Icelandic definitions]
% Personal information
\def\ecv@infosectionkey{\ecv@utf{Pers{\'o}nulegar uppl{\'y}singar}}
\def\ecv@namekey{\ecv@utf{Nafn}}
\def\ecv@addresskey{\ecv@utf{Heimilisfang/(-f{\"o}ng)}}
\def\ecv@telkey{\ecv@utf{S{\'\i}mi/(-ar)}}
\def\ecv@mobilekey{\ecv@utf{Fars{\'\i}mi}}
\def\ecv@faxkey{\ecv@utf{Br{\'e}fas{\'\i}mi}}
\def\ecv@emailkey{\ecv@utf{Netfang/(-f{\"o}ng)}}
\def\ecv@nationalitykey{\ecv@utf{{\TH}j{\'o}{\dh}erni}}
\def\ecv@birthkey{\ecv@utf{F{\ae}{\dh}ingardagur}}
\def\ecv@genderkey{\ecv@utf{Kyn}}
% Footer
\def\ecv@pagekey{\ecv@utf{S{\'\i}{\dh}a}}
\def\ecv@cvofkey{\ecv@utf{{\AE}vi{\'a}grip}}
% Language table
\def\ecv@mothertonguekey{\ecv@utf{M{\'o}{\dh}urm{\'a}l}}
\def\ecv@assesskey{\ecv@utf{Sj\'alfsmat}}
\def\ecv@levelkey{\ecv@utf{Evr{\'o}puvi{\dh}mi{\dh}}}
\def\ecv@understandkey{\ecv@utf{Skilningur}}
\def\ecv@speakkey{\ecv@utf{Talm{\'a}l}}
\def\ecv@writekey{\ecv@utf{Lestur}}
\def\ecv@listenkey{\ecv@utf{Hlustun}}
\def\ecv@readkey{\ecv@utf{Lestur}}
\def\ecv@interactkey{\ecv@utf{F{\ae}rni vi{\dh} {\th}{\'a}ttt{\"o}ku {\'\i} samt{\"o}lum}}
\def\ecv@productkey{\ecv@utf{F{\ae}rni til a{\dh} gera ykkur skiljanleg}}
\def\ecv@langfooterkey{\ecv@utf{Sameiginleg evr{\'o}psk vi{\dh}mi{\dh}}}
\def\ecv@cefbasickey{\ecv@utf{Byrjandi}}
\def\ecv@cefindepkey{\ecv@utf{Lengra komin(n)}}
\def\ecv@cefprofkey{\ecv@utf{Leikinn m{\'a}lnotandi}}

\renewcommand*\ecvtitle{\ecv@utf{\Large\textbf{E\ecv@kern u\ecv@kern
r\ecv@kern o\ecv@kern p\ecv@kern a\ecv@kern s\ecv@kern s}\\[5pt]
\Large\textbf{\ae\ecv@kern v\ecv@kern i\ecv@kern \'a\ecv@kern
g\ecv@kern r\ecv@kern i\ecv@kern p}}}
