%!TEX encoding = UTF-8 Unicode
%
% Translation completed on 2006/01/11
\ProvidesFile{ecvno.def}[europecv Norwegian definitions]
% Personal information
\def\ecv@infosectionkey{\ecv@utf{Personlige opplysninger}}
\def\ecv@namekey{\ecv@utf{Navn}}
\def\ecv@addresskey{\ecv@utf{Adresse(r)}}
\def\ecv@telkey{\ecv@utf{Telefonnumre}}
\def\ecv@mobilekey{\ecv@utf{Mobil}}
\def\ecv@faxkey{\ecv@utf{Faksnumre}}
\def\ecv@emailkey{\ecv@utf{E-postadresse(r)}}
\def\ecv@nationalitykey{\ecv@utf{Nasjonalitet(er)}}
\def\ecv@birthkey{\ecv@utf{F\o dselsdato}}
\def\ecv@genderkey{\ecv@utf{Kj\o nn}}
% Footer
\def\ecv@pagekey{\ecv@utf{Side}}
\def\ecv@cvofkey{\ecv@utf{Curriculum vit\ae\ for}}
% Language table
\def\ecv@mothertonguekey{\ecv@utf{Morsm\aa l}}
\def\ecv@assesskey{\ecv@utf{Egenvurdering}}
\def\ecv@levelkey{\ecv@utf{Europeisk niv\aa}}
\def\ecv@understandkey{\ecv@utf{Forst\aa else}}
\def\ecv@speakkey{\ecv@utf{Tale}}
\def\ecv@writekey{\ecv@utf{Skrift}}
\def\ecv@listenkey{\ecv@utf{Lytting}}
\def\ecv@readkey{\ecv@utf{Lesing}}
\def\ecv@interactkey{\ecv@utf{Interaksjon}}
\def\ecv@productkey{\ecv@utf{Muntlig produksjon}}
\def\ecv@langfooterkey{\ecv@utf{CEF-niv\aa. CEF (Common European Framework) er en felles europeisk referanseramme for spr\aa k.}}
\def\ecv@cefbasickey{\ecv@utf{Basisbruker}}
\def\ecv@cefindepkey{\ecv@utf{Selvstendig bruker}}
\def\ecv@cefprofkey{\ecv@utf{Avansert bruker}}
