%!TEX encoding = UTF-8 Unicode
%
% Translation completed on 2006/01/11
\ProvidesFile{ecvda.def}[europecv Danish definitions]
% Personal information
\def\ecv@infosectionkey{\ecv@utf{Personlige oplysninger}}
\def\ecv@namekey{\ecv@utf{Efternavn(e), fornavn(e) og mellemnavn(e)}}
\def\ecv@addresskey{\ecv@utf{Adresse(r)}}
\def\ecv@telkey{\ecv@utf{Telefon}}
\def\ecv@mobilekey{\ecv@utf{Mobil}}
\def\ecv@faxkey{\ecv@utf{Fax}}
\def\ecv@emailkey{\ecv@utf{E-mail-adresse(r)}}
\def\ecv@nationalitykey{\ecv@utf{Nationalitet(er)}}
\def\ecv@birthkey{\ecv@utf{F\o dselsdato}}
\def\ecv@genderkey{\ecv@utf{K\o n}}
% Footer
\def\ecv@pagekey{\ecv@utf{Side}}
\def\ecv@cvofkey{\ecv@utf{Curriculum vit\ae\ for}}
% Language table
\def\ecv@mothertonguekey{\ecv@utf{Modersm\aa l}}
\def\ecv@assesskey{\ecv@utf{Selvevaluering}}
\def\ecv@levelkey{\ecv@utf{Europ\ae isk niveau}}
\def\ecv@understandkey{\ecv@utf{Forst\aa}}
\def\ecv@speakkey{\ecv@utf{Tale}}
\def\ecv@writekey{\ecv@utf{Skrive}}
\def\ecv@listenkey{\ecv@utf{Lytte}}
\def\ecv@readkey{\ecv@utf{L\ae se}}
\def\ecv@interactkey{\ecv@utf{Samtale}}
\def\ecv@productkey{\ecv@utf{Redeg\o re}}
\def\ecv@langfooterkey{\ecv@utf{Europ\ae iske Referencerammes (CEF) niveau}}
\def\ecv@cefbasickey{\ecv@utf{Sprogbruger med basiskundskaber}}
\def\ecv@cefindepkey{\ecv@utf{Selvst\ae ndig sprogbruger}}
\def\ecv@cefprofkey{\ecv@utf{Kompetent sprogbruger}}

\renewcommand*\ecvtitle{\ecv@utf{\Large\textbf{E\ecv@kern u\ecv@kern
r\ecv@kern o\ecv@kern p\ecv@kern \ae\ecv@kern i\ecv@kern s\ecv@kern k}\\[5pt]
\Large\textbf{c\ecv@kern u\ecv@kern r\ecv@kern r\ecv@kern
i\ecv@kern c\ecv@kern u\ecv@kern l\ecv@kern u\ecv@kern m \ecv@kern v\ecv@kern
i\ecv@kern t\ecv@kern a\ecv@kern e}}}
