%!TEX encoding = UTF-8 Unicode
%
% Translation completed on 2006/01/13
\ProvidesFile{ecvcs.def}[europecv Czech definitions]
% Personal information
\def\ecv@infosectionkey{\ecv@utf{Osobn{\'\i} {\'u}daje}}
\def\ecv@namekey{\ecv@utf{Jm{\'e}no / P{\v r}{\'\i}jmen{\'\i}}}
\def\ecv@addresskey{\ecv@utf{Adresa}}
\def\ecv@telkey{\ecv@utf{Telefon}}
\def\ecv@mobilekey{\ecv@utf{Mobiln{\'\i} telefon}}
\def\ecv@faxkey{\ecv@utf{Fax}}
\def\ecv@emailkey{\ecv@utf{E-mail}}
\def\ecv@nationalitykey{\ecv@utf{St{\'a}tn{\'\i} p{\v r}{\'\i}slu{\v s}nost}}
\def\ecv@birthkey{\ecv@utf{Datum narozen{\'\i}}}
\def\ecv@genderkey{\ecv@utf{Pohlav{\'\i}}}
% Footer
\def\ecv@pagekey{\ecv@utf{Strana}}
\def\ecv@cvofkey{\ecv@utf{{\v Z}ivotopis}}
% Language table
\def\ecv@mothertonguekey{\ecv@utf{Mate{\v r}sk{\'y} jazyk(y)}}
\def\ecv@assesskey{\ecv@utf{Sebehodnocen{\'i}}}
\def\ecv@levelkey{\ecv@utf{Evropsk{\'a} {\'u}rove{\v n}}}
\def\ecv@understandkey{\ecv@utf{Porozum{\v e}n{\'\i}}}
\def\ecv@speakkey{\ecv@utf{Mluven{\'\i}}}
\def\ecv@writekey{\ecv@utf{Psan{\'\i}}}
\def\ecv@listenkey{\ecv@utf{Poslech}}
\def\ecv@readkey{\ecv@utf{{\v C}ten{\'\i}}}
\def\ecv@interactkey{\ecv@utf{{\'U}stn{\'\i} interakce}}
\def\ecv@productkey{\ecv@utf{Samostatn{\'y} {\'u}stn{\'\i} projev}}
\def\ecv@langfooterkey{\ecv@utf{Spole{\v c}n{\'y} evropsk{\'y} referen{\v c}n{\'\i} r{\'a}mec pro jazyky}}
\def\ecv@cefbasickey{\ecv@utf{U{\v z}ivatel z{\'a}klad{\r u} jazyka}}
\def\ecv@cefindepkey{\ecv@utf{Samostatn{\'y} u{\v z}ivatel}}
\def\ecv@cefprofkey{\ecv@utf{Zku{\v s}en{\'y} u{\v z}ivatel}}

\renewcommand*\ecvtitle{\ecv@utf{\Large\textbf{E\ecv@kern u\ecv@kern
r\ecv@kern o\ecv@kern p\ecv@kern a\ecv@kern s\ecv@kern s}\\[5pt]
\Large\textbf{{\v z}\ecv@kern i\ecv@kern v\ecv@kern o\ecv@kern
t\ecv@kern o\ecv@kern p\ecv@kern i\ecv@kern s}}}

