%!TEX encoding = UTF-8 Unicode
%
% Translation completed
\ProvidesFile{ecven.def}[europecv English definitions]
% Personal information
\def\ecv@infosectionkey{\ecv@utf{Personal information}}
\def\ecv@namekey{\ecv@utf{Surname(s) / First name(s)}}
\def\ecv@addresskey{\ecv@utf{Address(es)}}
\def\ecv@telkey{\ecv@utf{Telephone(s)}}
\def\ecv@mobilekey{\ecv@utf{Mobile}}
\def\ecv@faxkey{\ecv@utf{Fax(es)}}
\def\ecv@emailkey{\ecv@utf{Email(s)}}
\def\ecv@nationalitykey{\ecv@utf{Nationality(-ies)}}
\def\ecv@birthkey{\ecv@utf{Date of birth}}
\def\ecv@genderkey{\ecv@utf{Gender}}
% Footer
\def\ecv@pagekey{\ecv@utf{Page}}
\def\ecv@cvofkey{\ecv@utf{Curriculum vit\ae\ of}}
% Language table
\def\ecv@mothertonguekey{\ecv@utf{Mother tongue(s)}}
\def\ecv@assesskey{\ecv@utf{Self-assessment}}
\def\ecv@levelkey{\ecv@utf{European level}}
\def\ecv@understandkey{\ecv@utf{Understanding}}
\def\ecv@speakkey{\ecv@utf{Speaking}}
\def\ecv@writekey{\ecv@utf{Writing}}
\def\ecv@listenkey{\ecv@utf{Listening}}
\def\ecv@readkey{\ecv@utf{Reading}}
\def\ecv@interactkey{\ecv@utf{Spoken interaction}}
\def\ecv@productkey{\ecv@utf{Spoken production}}
\def\ecv@langfooterkey{\ecv@utf{Common European Framework of Reference (CEF) level}}
\def\ecv@cefbasickey{\ecv@utf{Basic user}}
\def\ecv@cefindepkey{\ecv@utf{Independent user}}
\def\ecv@cefprofkey{\ecv@utf{Proficient user}}

\providecommand*{\ecvtitle}{\ecv@utf{\Large\textbf{E\ecv@kern u\ecv@kern
r\ecv@kern o\ecv@kern p\ecv@kern a\ecv@kern s\ecv@kern s}\\[5pt]
\Large\textbf{C\ecv@kern u\ecv@kern r\ecv@kern r\ecv@kern
i\ecv@kern c\ecv@kern u\ecv@kern l\ecv@kern u\ecv@kern m \ecv@kern V\ecv@kern
i\ecv@kern t\ecv@kern a\ecv@kern e}}}