%!TEX encoding = UTF-8 Unicode
%
% Translation completed on 2006/01/11
\ProvidesFile{ecvsv.def}[europecv Swedish definitions]
% Personal information
\def\ecv@infosectionkey{\ecv@utf{Personuppgifter}}
\def\ecv@namekey{\ecv@utf{Efternamn / F\"ornamn}}
\def\ecv@addresskey{\ecv@utf{Adress(er)}}
\def\ecv@telkey{\ecv@utf{Telefonnummer}}
\def\ecv@mobilekey{\ecv@utf{Mobil}}
\def\ecv@faxkey{\ecv@utf{Faxnummer}}
\def\ecv@emailkey{\ecv@utf{E-postadress(er)}}
\def\ecv@nationalitykey{\ecv@utf{Medborgarskap}}
\def\ecv@birthkey{\ecv@utf{F\"odelsedatum}}
\def\ecv@genderkey{\ecv@utf{K\"on}}
% Footer
\def\ecv@pagekey{\ecv@utf{Sida}}
\def\ecv@cvofkey{\ecv@utf{Meritf\"orteckning f\"or}}
% Language table
\def\ecv@mothertonguekey{\ecv@utf{Modersm\aa l}}
\def\ecv@assesskey{\ecv@utf{Sj\"alvbed\"omning}}
\def\ecv@levelkey{\ecv@utf{Europeisk niv\aa}}
\def\ecv@understandkey{\ecv@utf{F\"orst\aa else}}
\def\ecv@speakkey{\ecv@utf{Tala}}
\def\ecv@writekey{\ecv@utf{Skriva}}
\def\ecv@listenkey{\ecv@utf{H\"orf\"orst\aa else}}
\def\ecv@readkey{\ecv@utf{L\"asf\"orst\aa else}}
\def\ecv@interactkey{\ecv@utf{Muntlig interaktion}}
\def\ecv@productkey{\ecv@utf{Muntlig produktion}}
\def\ecv@langfooterkey{\ecv@utf{Niv\aa n inom de Gemensamma europeiska referensramarna (CEF)}}
\def\ecv@cefbasickey{\ecv@utf{Den baspresterande spr\aa kanv\"andaren}}
\def\ecv@cefindepkey{\ecv@utf{Den sj\"alvst\"andige spr\aa kanv\"andaren}}
\def\ecv@cefprofkey{\ecv@utf{Den avancerade spr\aa kanv\"andaren}}

\renewcommand*\ecvtitle{\ecv@utf{\Large\textbf{E\ecv@kern u\ecv@kern
r\ecv@kern o\ecv@kern p\ecv@kern a\ecv@kern s\ecv@kern s}\\[5pt]
\Large\textbf{m\ecv@kern e\ecv@kern r\ecv@kern i\ecv@kern
t\ecv@kern f\ecv@kern {\"o}\ecv@kern r\ecv@kern t\ecv@kern e\ecv@kern c\ecv@kern
k\ecv@kern n\ecv@kern i\ecv@kern n\ecv@kern g\ecv@kern e\ecv@kern n\ecv@kern}}}
