%!TEX encoding = UTF-8 Unicode
%
% Translation yet to be finished
\ProvidesFile{ecvca.def}[europecv Catalan definitions]
% Personal information
\def\ecv@infosectionkey{\ecv@utf{Informaci\'o personal}}
\def\ecv@namekey{\ecv@utf{Nom}}
\def\ecv@addresskey{\ecv@utf{Adre\c{c}a }}
\def\ecv@telkey{\ecv@utf{Tel\`efon}}
\def\ecv@mobilekey{\ecv@utf{M\`obil: }}
\def\ecv@faxkey{\ecv@utf{Fax}}
\def\ecv@emailkey{\ecv@utf{Correu electr\`onic}}
\def\ecv@nationalitykey{\ecv@utf{Nacionalitat}}
\def\ecv@birthkey{\ecv@utf{Data de naixement}}
\def\ecv@genderkey{\ecv@utf{Gender}} % To be translated
% Footer
\def\ecv@pagekey{\ecv@utf{P\`agina}}
\def\ecv@cvofkey{\ecv@utf{Curriculum vit\ae\ de}}
% Language table
\def\ecv@mothertonguekey{\ecv@utf{Mother tongue(s)}} % To be translated
\def\ecv@assesskey{\ecv@utf{Self-assessment}} % To be translated
\def\ecv@levelkey{\ecv@utf{European level}} % To be translated
\def\ecv@understandkey{\ecv@utf{Understanding}} % To be translated
\def\ecv@speakkey{\ecv@utf{Speaking}} % To be translated
\def\ecv@writekey{\ecv@utf{Writing}} % To be translated
\def\ecv@listenkey{\ecv@utf{Listening}} % To be translated
\def\ecv@readkey{\ecv@utf{Reading}} % To be translated
\def\ecv@interactkey{\ecv@utf{Spoken interaction}} % To be translated
\def\ecv@productkey{\ecv@utf{Spoken production}} % To be translated
\def\ecv@langfooterkey{\ecv@utf{Common European Framework of Reference (CEF) level}} % To be translated
\def\ecv@cefbasickey{\ecv@utf{Basic user}}       % To be translated
\def\ecv@cefindepkey{\ecv@utf{Independent user}} % To be translated
\def\ecv@cefprofkey{\ecv@utf{Proficient user}}   % To be translated
