%!TEX encoding = UTF-8 Unicode
%
% Translation completed 06.02.2006.
\ProvidesFile{ecvsr.def}[europecv Serbian definitions]
% Personal information
\def\ecv@infosectionkey{\ecv@utf{Li{\v c}ni podaci}}
\def\ecv@namekey{\ecv@utf{Prezime~/ ime}}
\def\ecv@addresskey{\ecv@utf{Adresa}}
\def\ecv@telkey{\ecv@utf{Telefon}}
\def\ecv@mobilekey{\ecv@utf{Mobilan}}
\def\ecv@faxkey{\ecv@utf{Fax}}
\def\ecv@emailkey{\ecv@utf{E - mail}}
\def\ecv@nationalitykey{\ecv@utf{Nacionalnost}}
\def\ecv@birthkey{\ecv@utf{Datum ro{\dj}enja}}
\def\ecv@genderkey{\ecv@utf{Pol}}
% Footer
\def\ecv@pagekey{\ecv@utf{Strana}}
\def\ecv@cvofkey{\ecv@utf{Curriculum vit\ae\ -}}
% Language table
\def\ecv@mothertonguekey{\ecv@utf{Maternji jezik}}
\def\ecv@assesskey{\ecv@utf{Samovrednovanje}}
\def\ecv@levelkey{\ecv@utf{Evropski nivo}}
\def\ecv@understandkey{\ecv@utf{Razumevanje}}
\def\ecv@speakkey{\ecv@utf{Govor}}
\def\ecv@writekey{\ecv@utf{Pisanje}}
\def\ecv@listenkey{\ecv@utf{Slu{\v s}no razumevanje}}
\def\ecv@readkey{\ecv@utf{\v Citanje}}
\def\ecv@interactkey{\ecv@utf{Govorno sporazumevanje}}
\def\ecv@productkey{\ecv@utf{Samoizra\v zavanje}}
\def\ecv@langfooterkey{\ecv@utf{Zajedni\v cki evropski referencni okvir za jezike(CEF)}}
\def\ecv@cefbasickey{\ecv@utf{Osnovni korisnik}}
\def\ecv@cefindepkey{\ecv@utf{Samostalni korisnik}}
\def\ecv@cefprofkey{\ecv@utf{Osposobljeni korisnik}}

\providecommand*{\ecvtitle}{\ecv@utf{\Large\textbf{E\ecv@kern v\ecv@kern
r\ecv@kern o\ecv@kern p\ecv@kern s\ecv@kern k\ecv@kern i}\\[5pt]
\Large\textbf{C\ecv@kern u\ecv@kern r\ecv@kern r\ecv@kern
i\ecv@kern c\ecv@kern u\ecv@kern l\ecv@kern u\ecv@kern m \ecv@kern
V\ecv@kern i\ecv@kern t\ecv@kern a\ecv@kern e}}}
