%!TEX encoding = UTF-8 Unicode
%
% Translation completed on 2006/01/13
\ProvidesFile{ecvsk.def}[europecv Slovak definitions]
% Personal information
\def\ecv@infosectionkey{\ecv@utf{Osobn{\'e} {\'u}daje}}
\def\ecv@namekey{\ecv@utf{Priezvisko({\'a}) / Meno({\'a})}}
\def\ecv@addresskey{\ecv@utf{Adresa(y)}}
\def\ecv@telkey{\ecv@utf{Telef\'on(y)}}
\def\ecv@mobilekey{\ecv@utf{Mobil}}
\def\ecv@faxkey{\ecv@utf{Fax(y)}}
\def\ecv@emailkey{\ecv@utf{E-mail(y)}}
\def\ecv@nationalitykey{\ecv@utf{{\v S}t{\'a}tna(e) pr{\'\i}slu{\v s}nost'(ti)}}
\def\ecv@birthkey{\ecv@utf{D{\'a}tum narodenia}}
\def\ecv@genderkey{\ecv@utf{Pohlavie}}
% Footer
\def\ecv@pagekey{\ecv@utf{Strana}}
\def\ecv@cvofkey{\ecv@utf{{\v Z}ivotopis}}
% Language table
\def\ecv@mothertonguekey{\ecv@utf{Materinsk{\'y}({\'e}) jazyk(y)}}
\def\ecv@assesskey{\ecv@utf{Sebahodnotenie}}
\def\ecv@levelkey{\ecv@utf{Eur{\'o}pska {\'u}rove{\v n}}}
\def\ecv@understandkey{\ecv@utf{Porozumenie}}
\def\ecv@speakkey{\ecv@utf{Hovorenie}}
\def\ecv@writekey{\ecv@utf{P{\'\i}sanie}}
\def\ecv@listenkey{\ecv@utf{Po{\v c}{\'u}vanie}}
\def\ecv@readkey{\ecv@utf{{\v C}{\'\i}tanie}}
\def\ecv@interactkey{\ecv@utf{{\'U}stna interakcia}}
\def\ecv@productkey{\ecv@utf{Samostatn{\'y} {\'u}stny prejav}}
\def\ecv@langfooterkey{\ecv@utf{{\'U}rove{\v n} podl'a Spolo{\v c}n{\'e}ho eur{\'o}pskeho referen{\v c}n{\'e}ho r{\'a}mca (CEF)}}
\def\ecv@cefbasickey{\ecv@utf{Pou{\v z}{\'\i}vatel' z{\'a}kladn{\'e}ho jazyka}}
\def\ecv@cefindepkey{\ecv@utf{Samostatn{\'y} pou{\v z}{\'\i}vatel'}}
\def\ecv@cefprofkey{\ecv@utf{Sk{\'u}sen{\'y} pou{\v z}{\'\i}vatel'}}

\renewcommand*\ecvtitle{\ecv@utf{\Large\textbf{E\ecv@kern u\ecv@kern
r\ecv@kern o\ecv@kern p\ecv@kern a\ecv@kern s\ecv@kern s}\\[5pt]
\Large\textbf{{\v Z}\ecv@kern i\ecv@kern v\ecv@kern o\ecv@kern
t\ecv@kern o\ecv@kern p\ecv@kern i\ecv@kern s}}}
