%!TEX encoding = UTF-8 Unicode
%
% Translation completed on 2006/01/13
\ProvidesFile{ecvsl.def}[europecv Slovenian definitions]
% Personal information
\def\ecv@infosectionkey{\ecv@utf{Osebni podatki}}
\def\ecv@namekey{\ecv@utf{Ime~/ Priimek}}
\def\ecv@addresskey{\ecv@utf{Naslov}}
\def\ecv@telkey{\ecv@utf{Telefon}}
\def\ecv@mobilekey{\ecv@utf{Prenosni telefon}}
\def\ecv@faxkey{\ecv@utf{Telefaks}}
\def\ecv@emailkey{\ecv@utf{E-po{\v s}ta}}
\def\ecv@nationalitykey{\ecv@utf{Dr{\v z}avljanstvo}}
\def\ecv@birthkey{\ecv@utf{Datum rojstva}}
\def\ecv@genderkey{\ecv@utf{Spol}}
% Footer
\def\ecv@pagekey{\ecv@utf{Stran}}
\def\ecv@cvofkey{\ecv@utf{{\v Z}ivljenjepis}}
% Language table
\def\ecv@mothertonguekey{\ecv@utf{Materni jezik(i)}}
\def\ecv@assesskey{\ecv@utf{Samovrednotenje}}
\def\ecv@levelkey{\ecv@utf{Evropska raven}}
\def\ecv@understandkey{\ecv@utf{Razumevanje}}
\def\ecv@speakkey{\ecv@utf{Govorjenje}}
\def\ecv@writekey{\ecv@utf{Pisanje}}
\def\ecv@listenkey{\ecv@utf{Slu{\v s}no razumevanje}}
\def\ecv@readkey{\ecv@utf{Bralno razumevanje}}
\def\ecv@interactkey{\ecv@utf{Govorno sporazumevanje}}
\def\ecv@productkey{\ecv@utf{Govorno sporo{\v c}anje}}
\def\ecv@langfooterkey{\ecv@utf{Skupni evropski referen{\v c}ni okvir za jezike}}
\def\ecv@cefbasickey{\ecv@utf{Osnovni uporabnik}}
\def\ecv@cefindepkey{\ecv@utf{Samostojni uporabnik}}
\def\ecv@cefprofkey{\ecv@utf{Usposobljeni uporabnik}}

\renewcommand*\ecvtitle{\ecv@utf{\Large\textbf{E\ecv@kern u\ecv@kern
r\ecv@kern o\ecv@kern p\ecv@kern a\ecv@kern s\ecv@kern s}\\[5pt]
\Large\textbf{{\v z}\ecv@kern i\ecv@kern v\ecv@kern l\ecv@kern
j\ecv@kern e\ecv@kern n\ecv@kern j\ecv@kern e\ecv@kern p\ecv@kern i\ecv@kern
s}}}
