%!TEX encoding = UTF-8 Unicode
%
% Translation completed on 2005/05/05
\ProvidesFile{ecvfr.def}[europecv French definitions]
% Informations personnelles
\def\ecv@infosectionkey{\ecv@utf{Informations personnelles}}
\def\ecv@namekey{\ecv@utf{Nom(s) / Pr\'enom(s)}}
\def\ecv@addresskey{\ecv@utf{Adresse(s)}}
\def\ecv@telkey{\ecv@utf{T\'el\'ephone(s)}}
\def\ecv@mobilekey{\ecv@utf{Portable}}
\def\ecv@faxkey{\ecv@utf{T\'el\'ecopie(s)}}
\def\ecv@emailkey{\ecv@utf{Courrier(s) \'electronique(s)}}
\def\ecv@nationalitykey{\ecv@utf{Nationalit\'e(s)}}
\def\ecv@birthkey{\ecv@utf{Date de naissance}}
\def\ecv@genderkey{\ecv@utf{Sexe}}
% Pied de page
\def\ecv@pagekey{\ecv@utf{Page}}
\def\ecv@cvofkey{\ecv@utf{Curriculum vit\ae\ de}}
% Grille d'Autovaluation des langues
\def\ecv@mothertonguekey{\ecv@utf{Langue(s) maternelle(s)}}
\def\ecv@assesskey{\ecv@utf{Auto \'evaluation}}
\def\ecv@levelkey{\ecv@utf{Niveau europ\'een}}
\def\ecv@understandkey{\ecv@utf{Comprendre}}
\def\ecv@speakkey{\ecv@utf{Parler}}
\def\ecv@writekey{\ecv@utf{\'Ecrire}}
\def\ecv@listenkey{\ecv@utf{\'Ecouter}}
\def\ecv@readkey{\ecv@utf{Lire}}
\def\ecv@interactkey{\ecv@utf{Prendre part \`a une conversation}}
\def\ecv@productkey{\ecv@utf{S'exprimer oralement en continu}}
\def\ecv@langfooterkey{\ecv@utf{Niveau du Cadre europ\'een commun de r\'ef\'erence (CECR)}}
\def\ecv@cefbasickey{\ecv@utf{Utilisateur \'el\'ementaire}}
\def\ecv@cefindepkey{\ecv@utf{Utilisateur Ind\'ependant}}
\def\ecv@cefprofkey{\ecv@utf{Utilisateur exp\'eriment\'e}}

\renewcommand*\ecvtitle{\ecv@utf{\Large\textbf{C\ecv@kern u\ecv@kern r\ecv@kern r\ecv@kern i\ecv@kern c\ecv@kern u\ecv@kern l\ecv@kern u\ecv@kern m \ecv@kern v\ecv@kern i\ecv@kern t\ecv@kern a\ecv@kern e}\\[5pt]
\Large\textbf{E\ecv@kern u\ecv@kern
r\ecv@kern o\ecv@kern p\ecv@kern a\ecv@kern s\ecv@kern s}}}
